#
# Copyright 2002 Roland Stigge
#
# This file is part of ImageWorkshop
#
# ImageWorkshop is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# ImageWorkshop is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with ImageWorkshop; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

#
# this module contains the predefined filter matrices for convolution filters
#

matrices = [
    ("Identity", [[0, 0, 0, 0, 0],
                  [0, 0, 0, 0, 0],
                  [0, 0, 1, 0, 0],
                  [0, 0, 0, 0, 0],
                  [0, 0, 0, 0, 0]]),
    ("Horizontal edge detect", [[0, 0, 0, 0, 0],
                                [0, 0, 0, 0, 0],
                                [0, 0, 1,-1, 0],
                                [0, 0, 0, 0, 0],
                                [0, 0, 0, 0, 0]]),
    ("Vertical edge detect", [[0, 0, 0, 0, 0],
                              [0, 0, 0, 0, 0],
                              [0, 0, 1, 0, 0],
                              [0, 0,-1, 0, 0],
                              [0, 0, 0, 0, 0]]),
    ("Diagonal edge detect", [[0, 0, 0, 0, 0],
                              [0, 0, 0, 0, 0],
                              [0, 0, 1, 0, 0],
                              [0, 0, 0,-1, 0],
                              [0, 0, 0, 0, 0]]),
    ("Sharpen", [[ 0, 0, 0, 0, 0],
                 [ 0, 0,-1, 0, 0],
                 [ 0,-1, 5,-1, 0],
                 [ 0, 0,-1, 0, 0],
                 [ 0, 0, 0, 0, 0]]),
    ("3x3 Average", [[0, 0, 0, 0, 0],
                     [0, 1, 1, 1, 0],
                     [0, 1, 1, 1, 0],
                     [0, 1, 1, 1, 0],
                     [0, 0, 0, 0, 0]]),
    ("3x3 Gauss", [[0, 0, 0, 0, 0],
                   [0, 1, 2, 1, 0],
                   [0, 2, 4, 2, 0],
                   [0, 1, 2, 1, 0],
                   [0, 0, 0, 0, 0]]),
    ("3x3 Horizontal edge detect", [[0, 0, 0, 0, 0],
                                    [0, 1, 0,-1, 0],
                                    [0, 1, 0,-1, 0],
                                    [0, 1, 0,-1, 0],
                                    [0, 0, 0, 0, 0]]),
    ("3x3 Vertical edge detect", [[0, 0, 0, 0, 0],
                                  [0, 1, 1, 1, 0],
                                  [0, 0, 0, 0, 0],
                                  [0,-1,-1,-1, 0],
                                  [0, 0, 0, 0, 0]]),
    ("3x3 Diagonal edge detect", [[0, 0, 0, 0, 0],
                                  [0, 1, 1, 0, 0],
                                  [0, 1, 0,-1, 0],
                                  [0, 0,-1,-1, 0],
                                  [0, 0, 0, 0, 0]]),
    ("3x3 Horizontal Sobel", [[0, 0, 0, 0, 0],
                              [0, 1, 0,-1, 0],
                              [0, 2, 0,-2, 0],
                              [0, 1, 0,-1, 0],
                              [0, 0, 0, 0, 0]]),
    ("3x3 Vertical Sobel", [[0, 0, 0, 0, 0],
                            [0, 1, 2, 1, 0],
                            [0, 0, 0, 0, 0],
                            [0,-1,-2,-1, 0],
                            [0, 0, 0, 0, 0]]),
    ("3x3 2D-Laplace", [[0, 0, 0, 0, 0],
                        [0, 0, 1, 0, 0],
                        [0, 1,-4, 1, 0],
                        [0, 0, 1, 0, 0],
                        [0, 0, 0, 0, 0]]),
    ("3x3 Horizontal Laplace", [[0, 0, 0, 0, 0],
                                [0,-1, 2,-1, 0],
                                [0,-1, 2,-1, 0],
                                [0,-1, 2,-1, 0],
                                [0, 0, 0, 0, 0]]),
    ("3x3 Vertical Laplace", [[0, 0, 0, 0, 0],
                              [0,-1,-1,-1, 0],
                              [0, 2, 2, 2, 0],
                              [0,-1,-1,-1, 0],
                              [0, 0, 0, 0, 0]]),
    ("5x5 Average", [[1, 1, 1, 1, 1],
                     [1, 1, 1, 1, 1],
                     [1, 1, 1, 1, 1],
                     [1, 1, 1, 1, 1],
                     [1, 1, 1, 1, 1]]),
    ("5x5 Gauss", [[1, 4, 6, 4, 1],
                   [4,16,24,16, 4],
                   [6,24,36,24, 6],
                   [4,16,24,16, 4],
                   [1, 4, 6, 4, 1]]),
    ("5x5 Laplace", [[0, 0, 1, 0, 0],
                     [0, 1, 4, 1, 0],
                     [1, 4,-64,4, 1],
                     [0, 1, 4, 1, 0],
                     [0, 0, 1, 0, 0]]),
    ("Roberts Cross", [[-1, 0, 0, 0,-1],
                       [ 0, 0, 0, 0, 0],
                       [ 0, 0, 0, 0, 0],
                       [ 0, 0, 0, 0, 0],
                       [ 0, 0, 0, 0, 0],
                       [ 1, 0, 0, 0, 1]]),
    ("Stirling Differentiator", [[-1, 8, 0,-8, 1],
                                 [-1, 8, 0,-8, 1],
                                 [-1, 8, 0,-8, 1],
                                 [-1, 8, 0,-8, 1],
                                 [-1, 8, 0,-8, 1]]),
     ]
